dm 'log' clear;
dm 'odsresults' clear;

%let SASroot = C:\Eigene\Code\Data;
%let outputroot = C:\Eigene\Code\Data;

data boiling;
  format temp 5.1 press 7.3 logpress 7.4 hlogpress 7.2;
	  label temp = 'Boiling Point (F)'
          press = 'Pressure (Hg)'
					hlogpress = '100 x Log Pressure (Hg)';
  input temp press logpress hlogpress;
  datalines;
194.5 20.79 1.3179 131.79
194.3 20.79 1.3179 131.79
197.9 22.40 1.3502 135.02
198.4 22.67 1.3555 135.55
199.4 23.15 1.3646 136.46
199.9 23.35 1.3683 136.83
200.9 23.89 1.3782 137.82
201.1 23.99 1.3800 138.00
201.4 24.02 1.3806 138.06
201.3 24.01 1.3804 138.04
203.6 25.14 1.4004 140.04
204.6 26.57 1.4244 142.44
209.5 28.49 1.4547 145.47
208.6 27.76 1.4434 144.34
210.7 29.04 1.4630 146.30
211.9 29.88 1.4754 147.54
212.2 30.06 1.4780 147.80
  ;
run;

goptions reset=all;
*options nogstyle fontrendering=host_pixels;
options orientation=landscape nonumber nodate papersize=letter;*( "11in", "7in" );
goptions cback=white ctitle=black ctext=black ftitle='Times/bold' ftext='Times' reset=( axis symbol );
  *xmax=4in hsize=3.5in;
symbol1 l=20 h=2 c=red;
symbol2 i=join c=blue;
symbol3 i=join l=20 c=purple;
axis1 offset=( 1 cm ) label=( height=1.6 ) order=( 194 to 214 by 4 ) minor=( number=4 );
axis2 offset=( 1 cm ) label=( angle=90 height=1.6 ) order=( 20 to 31 by 1 ) minor=(number = 1 );
axis3 offset=( 1 cm ) label=( angle=90 height=1.6 ) order=( 130 to 150 by 5 )
  minor=(number = 4 );
footnote1;
title 'Boiling Point vs Pressure';

ods pdf file="&outputroot\output1.pdf" bookmarklist=OFF;

proc gplot data=boiling;
  format press temp 4.;
  plot press*temp=1 / haxis=axis1 vaxis=axis2 overlay;
run;

ods pdf close;

ods pdf file="&outputroot\output2.pdf" bookmarklist=OFF;

proc reg data=boiling noprint;
  format press temp 4.;
  model press = temp;
  plot press*temp / vaxis=( 20 to 31 by 1 ) haxis=( 194 to 214 by 4 ) nostat nomodel;
run;

ods pdf close;

title 'Boiling Point vs Model 1 Residual';

ods pdf file="&outputroot\output3.pdf" bookmarklist=OFF;

proc reg data=boiling noprint;
  format press temp 4.;
  model press = temp;
  plot residual.*temp / haxis=( 194 to 214 by 4 ) nostat nomodel;
run;
quit;

ods pdf close;

title 'Model 1 Residuals vs Normal Quantiles';

ods pdf file="&outputroot\output3b.pdf" bookmarklist=OFF;

proc reg data=boiling noprint;
  format press temp 4.;
  model press = temp;
  plot residual.*nqq. / nostat nomodel noline;
run;
quit;

ods pdf close;

title 'Boiling Point vs Log Pressure';

ods pdf file="&outputroot\output4.pdf" bookmarklist=OFF;

proc reg data=boiling noprint;
  format hlogpress temp 4.;
  model hlogpress = temp;
  plot hlogpress*temp / haxis=( 194 to 214 by 4 ) nostat nomodel;
run;

ods pdf close;

title 'Boiling Point vs Model 2 Residual';

ods pdf file="&outputroot\output5.pdf" bookmarklist=OFF;

proc reg data=boiling noprint;
  format hlogpress temp 4.;
  model hlogpress = temp;
  plot residual.*temp / haxis=( 194 to 214 by 4 ) nostat nomodel;
run;
quit;

ods pdf close;

title 'Boiling Point vs Log Pressure';

ods listing;

proc reg data=boiling;
  format hlogpress temp 4.;
  model hlogpress = temp;
run;
quit;

ods listing close;


* Democracy Data Set;

data lgdp;
	format id gurr 4. lgdp 5.2 comm 2.;
	label gurr = "%bquote(Gurr's) Index (1995)"
	      lgdp = 'Log GDP (1985)';
	infile "&outputroot\Gurr-LogGDP.txt" dlm=' ' missover dsd firstobs=2;
	input id gurr lgdp comm;
run;

title 'log GDP vs Democracy Index';


ods pdf file="&outputroot\output6.pdf" bookmarklist=OFF;

proc reg data=lgdp noprint;
	model gurr = lgdp;
	plot gurr*lgdp / nostat nomodel;
run;
quit;

ods pdf close;

ods listing;

proc reg data=lgdp;
	model gurr = lgdp;
run;
quit;

ods listing close;


* Time Series Data;

data valves;
	format date mmyys. shipments orders 6.;
	informat date mmddyy10. shipments orders 6.;
	infile "&outputroot\Valves.csv" dlm=',' missover dsd firstobs=2;
	input date shipments orders;
	label shipments = 'Shipments'
	      orders = 'Orders'
        date = 'Date';
run;

title 'Valve Orders vs Shipments';

ods pdf file="&outputroot\output7.pdf" bookmarklist=OFF;

proc reg data=valves noprint;
	format shipments orders comma7.;
	model shipments = orders;
	plot shipments*orders / nostat nomodel;
run;
quit;

ods pdf close;

title 'Valve Orders vs Model 3 Residual';

ods pdf file="&outputroot\output8.pdf" bookmarklist=OFF;

proc reg data=valves noprint;
	format shipments orders comma7.;
	model shipments = orders;
	plot residual.*orders / nostat nomodel;
run;
quit;

ods pdf close;

title 'Predicted Values vs Model 3 Residual';

ods pdf file="&outputroot\output9.pdf" bookmarklist=OFF;

proc reg data=valves noprint;
	format shipments orders comma7.;
	model shipments = orders;
	plot residual.*predicted. / nostat nomodel;
*	plot residual.*date;
run;
quit;

ods pdf close;

title 'Date vs Model 3 Residual';

ods pdf file="&outputroot\output10.pdf" bookmarklist=OFF;

proc reg data=valves noprint;
  var date;
	format shipments orders comma7.;
	model shipments = orders;
*	plot residual.*shipments / nostat nomodel;
	plot residual.*date / nostat nomodel;
run;
quit;

ods pdf close;

title 'Valve Orders vs Shipments';

ods listing;

proc reg data=valves;
  var date;
	format shipments orders comma7.;
	model shipments = orders;
run;
quit;

ods listing close;

symbol1 i=join l=1 c=red;
symbol2 i=join l=1 c=blue;
axis3 offset=( 1 cm ) label=( height=1.6 'Date' ) order=( '01jan1984'd to '01jul1988'd by month4 ) minor=( number=3 );
axis4 offset=( 1 cm ) label=( angle=90 height=1.6 'Orders/Shipments' ) order=( 33000 to 45000 by 4000 ) minor=( number=3 );

ods pdf file="&outputroot\output11.pdf" bookmarklist=OFF;

proc gplot data=valves;
  format shipments orders comma9. date mmyys5.;
	plot shipments*date=1 
       orders*date=2 / haxis=axis3 vaxis=axis4 overlay;
run;
quit;

ods pdf close;
